<?php

namespace Lavalite\Gallery\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Lavalite\Gallery\Interfaces\GalleryCategoryRepositoryInterface;

class GalleryCategoryPublicController extends BaseController
{
    // use GalleryCategoryWorkflow;

    /**
     * Constructor.
     *
     * @param type \Lavalite\GalleryCategory\Interfaces\GalleryCategoryRepositoryInterface $gallery_category
     *
     * @return type
     */
    public function __construct(GalleryCategoryRepositoryInterface $gallery_category)
    {
        $this->repository = $gallery_category;
        parent::__construct();
    }

    /**
     * Show gallery_category's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $gallery_categories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$gallery::$gallery_category.names'))
            ->view('$gallery::public.gallery_category.index')
            ->data(compact('$gallery_categories'))
            ->output();
    }

    /**
     * Show gallery_category's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $gallery_categories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$gallery::$gallery_category.names'))
            ->view('$gallery::public.gallery_category.index')
            ->data(compact('$gallery_categories'))
            ->output();
    }

    /**
     * Show gallery_category.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $gallery_category = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$gallery_category->name . trans('$gallery::$gallery_category.name'))
            ->view('$gallery::public.gallery_category.show')
            ->data(compact('$gallery_category'))
            ->output();
    }

}
