<?php

namespace Lavalite\Gallery\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Gallery\Models\GalleryCategory;

class GalleryCategoryPolicy
{

    /**
     * Determine if the given user can view the gallery_category.
     *
     * @param UserPolicy $user
     * @param GalleryCategory $gallery_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, GalleryCategory $gallery_category)
    {
        if ($user->canDo('gallery.gallery_category.view') && $user->isAdmin()) {
            return true;
        }

        return $gallery_category->user_id == user_id() && $gallery_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a gallery_category.
     *
     * @param UserPolicy $user
     * @param GalleryCategory $gallery_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('gallery.gallery_category.create');
    }

    /**
     * Determine if the given user can update the given gallery_category.
     *
     * @param UserPolicy $user
     * @param GalleryCategory $gallery_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, GalleryCategory $gallery_category)
    {
        if ($user->canDo('gallery.gallery_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $gallery_category->user_id == user_id() && $gallery_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given gallery_category.
     *
     * @param UserPolicy $user
     * @param GalleryCategory $gallery_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, GalleryCategory $gallery_category)
    {
        return $gallery_category->user_id == user_id() && $gallery_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given gallery_category.
     *
     * @param UserPolicy $user
     * @param GalleryCategory $gallery_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, GalleryCategory $gallery_category)
    {
        if ($user->canDo('gallery.gallery_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given gallery_category.
     *
     * @param UserPolicy $user
     * @param GalleryCategory $gallery_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, GalleryCategory $gallery_category)
    {
        if ($user->canDo('gallery.gallery_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
